Module coord

Module coord 

Structs

Bounds
A 2D axis-aligned bounding box in CRS-native units.
Coord
A 2D coordinate.
Coord3D
A 3D coordinate.

Traits

Transformable
Trait for types that can be transformed through a Transform.
Transformable3D
Trait for types that can be transformed through a Transform while preserving an ellipsoidal height component.