Transformable3D

Trait Transformable3D 

pub trait Transformable3D: Sized {
    // Required methods
    fn into_coord3d(self) -> Coord3D;
    fn from_coord3d(c: Coord3D) -> Self;
}
Trait for types that can be transformed through a Transform while preserving an ellipsoidal height component.

The transform returns the same type as the input, so (f64, f64, f64) in gives (f64, f64, f64) out and Coord3D in gives Coord3D out.

Required Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl Transformable3D for (f64, f64, f64)

Implementors