pub struct LinearUnit { /* private fields */ }Expand description
A coordinate system’s projected linear unit.
The stored value is the conversion factor from one native unit to meters.
Implementations
Sourceimpl LinearUnit
impl LinearUnit
Sourcepub const fn meter() -> Self
pub const fn meter() -> Self
Alias for LinearUnit::metre.
Sourcepub const fn kilometer() -> Self
pub const fn kilometer() -> Self
Alias for LinearUnit::kilometre.
Sourcepub const fn us_survey_foot() -> Self
pub const fn us_survey_foot() -> Self
US survey foot-based projected coordinates.
Sourcepub fn from_meters_per_unit(meters_per_unit: f64) -> Result<Self>
pub fn from_meters_per_unit(meters_per_unit: f64) -> Result<Self>
Construct a custom projected linear unit from its meter conversion factor.
Sourcepub const fn meters_per_unit(self) -> f64
pub const fn meters_per_unit(self) -> f64
Return the number of meters represented by one native projected unit.
Sourcepub const fn to_meters(self, value: f64) -> f64
pub const fn to_meters(self, value: f64) -> f64
Convert a native projected coordinate value into meters.
Sourcepub const fn from_meters(self, value: f64) -> f64
pub const fn from_meters(self, value: f64) -> f64
Convert a meter value into the native projected unit.