pub enum DatumToWgs84 {
Identity,
Helmert(HelmertParams),
GridShift(Box<DatumGridShift>),
Unknown,
}Expand description
Explicit WGS84 relationship for a datum.
Variants
Identity
The datum can be treated as WGS84-compatible in the current model.
Helmert(HelmertParams)
The datum requires the provided Helmert transform to reach WGS84.
GridShift(Box<DatumGridShift>)
The datum requires horizontal grid interpolation to reach WGS84.
Unknown
The datum’s path to WGS84 is not known.
Implementations
Sourceimpl DatumToWgs84
impl DatumToWgs84
pub fn uses_grid_shift(&self) -> bool