TransformableGeometry

Trait TransformableGeometry 

pub trait TransformableGeometry: Sized {
    // Required method
    fn transform_geometry(self, transform: &Transform) -> Result<Self>;
}
Trait for geo-types geometries that can be transformed as whole values.

Implementations transform coordinates in storage order and return the first coordinate error without producing a partially transformed geometry.

Required Methods

fn transform_geometry(self, transform: &Transform) -> Result<Self>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl TransformableGeometry for Coord<f64>

Available on crate feature geo-types only.
Source

fn transform_geometry(self, transform: &Transform) -> Result<Self>

Source

impl TransformableGeometry for Geometry<f64>

Available on crate feature geo-types only.
Source

fn transform_geometry(self, transform: &Transform) -> Result<Self>

Source

impl TransformableGeometry for GeometryCollection<f64>

Available on crate feature geo-types only.
Source

fn transform_geometry(self, transform: &Transform) -> Result<Self>

Source

impl TransformableGeometry for Line<f64>

Available on crate feature geo-types only.
Source

fn transform_geometry(self, transform: &Transform) -> Result<Self>

Source

impl TransformableGeometry for LineString<f64>

Available on crate feature geo-types only.
Source

fn transform_geometry(self, transform: &Transform) -> Result<Self>

Source

impl TransformableGeometry for MultiLineString<f64>

Available on crate feature geo-types only.
Source

fn transform_geometry(self, transform: &Transform) -> Result<Self>

Source

impl TransformableGeometry for MultiPoint<f64>

Available on crate feature geo-types only.
Source

fn transform_geometry(self, transform: &Transform) -> Result<Self>

Source

impl TransformableGeometry for MultiPolygon<f64>

Available on crate feature geo-types only.
Source

fn transform_geometry(self, transform: &Transform) -> Result<Self>

Source

impl TransformableGeometry for Point<f64>

Available on crate feature geo-types only.
Source

fn transform_geometry(self, transform: &Transform) -> Result<Self>

Source

impl TransformableGeometry for Polygon<f64>

Available on crate feature geo-types only.
Source

fn transform_geometry(self, transform: &Transform) -> Result<Self>

Source

impl TransformableGeometry for Rect<f64>

Available on crate feature geo-types only.
Source

fn transform_geometry(self, transform: &Transform) -> Result<Self>

Source

impl TransformableGeometry for Triangle<f64>

Available on crate feature geo-types only.
Source

fn transform_geometry(self, transform: &Transform) -> Result<Self>

Implementors