Transformable

Trait Transformable 

pub trait Transformable: Sized {
    // Required methods
    fn into_coord(self) -> Coord;
    fn from_coord(c: Coord) -> Self;
}
Trait for types that can be transformed through a Transform.

The transform returns the same type as the input, so geo_types::Coord<f64> in gives geo_types::Coord<f64> out, and (f64, f64) in gives (f64, f64) out.

Required Methods

fn into_coord(self) -> Coord

fn from_coord(c: Coord) -> Self

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl Transformable for (f64, f64)

Source

impl Transformable for Coord<f64>

Available on crate feature geo-types only.

Implementors

Source

impl Transformable for proj_core::coord::Coord