LinearUnit

Struct LinearUnit 

pub struct LinearUnit { /* private fields */ }
A coordinate system’s projected linear unit.

The stored value is the conversion factor from one native unit to meters.

Implementations

Source

impl LinearUnit

pub const fn metre() -> Self

Metre-based projected coordinates.

pub const fn meter() -> Self

Alias for LinearUnit::metre.

pub const fn kilometre() -> Self

Kilometer-based projected coordinates.

pub const fn kilometer() -> Self

pub const fn foot() -> Self

International foot-based projected coordinates.

pub const fn us_survey_foot() -> Self

US survey foot-based projected coordinates.

pub fn from_meters_per_unit(meters_per_unit: f64) -> Result<Self>

Construct a custom projected linear unit from its meter conversion factor.

pub const fn meters_per_unit(self) -> f64

Return the number of meters represented by one native projected unit.

pub const fn to_meters(self, value: f64) -> f64

Convert a native projected coordinate value into meters.

pub const fn from_meters(self, value: f64) -> f64

Convert a meter value into the native projected unit.